@@ -1,5 +1,5 @@
 #######################################################################
-# $Id: Directory.pm,v 1.12 2010-11-26 20:55:10 dpchrist Exp $
+# $Id: Directory.pm,v 1.13 2010-11-27 03:37:58 dpchrist Exp $
 #######################################################################
 # package:
 #----------------------------------------------------------------------
@@ -21,7 +21,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = qw();
 
-our $VERSION = sprintf("%d.%03d", q$Revision: 1.12 $ =~ /(\d+)/g);
+our $VERSION = sprintf("%d.%03d", q$Revision: 1.13 $ =~ /(\d+)/g);
 
 #######################################################################
 # uses:
@@ -50,7 +50,7 @@ Dpchrist::Directory - utility subroutines for directories
 
 =head1 DESCRIPTION
 
-This documentation describes module revision $Revision: 1.12 $.
+This documentation describes module revision $Revision: 1.13 $.
 
 
 This is alpha test level software
@@ -340,16 +340,32 @@ See 'perldoc Export' for everything in between.
 
 =head1 INSTALLATION
 
-    perl Makefile.PL
-    make
-    make test
-    make install
+Old school:
+
+    $ perl Makefile.PL
+    $ make
+    $ make test
+    $ make install
+
+Minimal:
+
+    $ cpan Dpchrist::Debug
+
+Complete:
+
+    $ cpan Bundle::Dpchrist
+
+The following warning may be safely ignored:
+
+    Can't locate Dpchrist/Module/MakefilePL.pm in @INC (@INC contains: /
+    etc/perl /usr/local/lib/perl/5.10.0 /usr/local/share/perl/5.10.0 /us
+    r/lib/perl5 /usr/share/perl5 /usr/lib/perl/5.10 /usr/share/perl/5.10
+    /usr/local/lib/site_perl .) at Makefile.PL line 22.
 
 
-=head1 DEPENDENCIES
+=head2 PREREQUISITES
 
-    Dpchirst::Debug
-    Dpchrist::Module
+See Makefile.PL in the source distribution root directory.
  
 
 =head1 AUTHOR
